==> haskell-control-monad-free-0.6.2-18-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-control-monad-free.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 control-monad-free
version:              0.6.2
visibility:           public
id:                   control-monad-free-0.6.2-EzZM364gZoH74r4JAMXt4u
key:                  control-monad-free-0.6.2-EzZM364gZoH74r4JAMXt4u
license:              LicenseRef-PublicDomain
maintainer:           pepeiborra@gmail.com
author:               Luke Palmer, Pepe Iborra
stability:            stable
homepage:             http://github.com/pepeiborra/control-monad-free
synopsis:             Free monads and monad transformers
description:
    This package provides datatypes to construct Free monads,
    Free monad transformers, and useful instances. In addition it
    provides the constructs to avoid quadratic complexity of left
    associative bind, as explained in:

    * Janis Voigtlander, /Asymptotic Improvement of Computations over Free Monads, MPC'\''08/

category:             Control, Monads
abi:                  652f6595bf9b8d6afc464757dd1e0400
exposed:              True
exposed-modules:
    Control.Monad.Free Control.Monad.Free.Improve
    Control.Monad.Free.Zip

import-dirs:          /usr/lib/ghc-9.2.8/site-local/control-monad-free-0.6.2
library-dirs:         /usr/lib/ghc-9.2.8/site-local/control-monad-free-0.6.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-control-monad-free
hs-libraries:         HScontrol-monad-free-0.6.2-EzZM364gZoH74r4JAMXt4u
depends:              base-4.16.4.0 transformers-0.5.6.2
haddock-interfaces:
    /usr/share/doc/haskell-control-monad-free/html/control-monad-free.haddock

haddock-html:         /usr/share/doc/haskell-control-monad-free/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-control-monad-free-0.6.2-19-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-control-monad-free.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 control-monad-free
version:              0.6.2
visibility:           public
id:                   control-monad-free-0.6.2-Bsk294wsAdBAFVbMh4Lqn8
key:                  control-monad-free-0.6.2-Bsk294wsAdBAFVbMh4Lqn8
license:              LicenseRef-PublicDomain
maintainer:           pepeiborra@gmail.com
author:               Luke Palmer, Pepe Iborra
stability:            stable
homepage:             http://github.com/pepeiborra/control-monad-free
synopsis:             Free monads and monad transformers
description:
    This package provides datatypes to construct Free monads,
    Free monad transformers, and useful instances. In addition it
    provides the constructs to avoid quadratic complexity of left
    associative bind, as explained in:

    * Janis Voigtlander, /Asymptotic Improvement of Computations over Free Monads, MPC'\''08/

category:             Control, Monads
abi:                  4a69be01fe05544e408941e63b64c5ec
exposed:              True
exposed-modules:
    Control.Monad.Free Control.Monad.Free.Improve
    Control.Monad.Free.Zip

import-dirs:          /usr/lib/ghc-9.4.8/site-local/control-monad-free-0.6.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/control-monad-free-0.6.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/control-monad-free-0.6.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-control-monad-free
hs-libraries:         HScontrol-monad-free-0.6.2-Bsk294wsAdBAFVbMh4Lqn8
depends:              base-4.17.2.1 transformers-0.5.6.2
haddock-interfaces:
    /usr/share/doc/haskell-control-monad-free/html/control-monad-free.haddock

haddock-html:         /usr/share/doc/haskell-control-monad-free/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
